@@ -10,18 +10,18 @@ from typing import Dict, List, Optional
 from ycontract import contract
 
 from exclock.sound_player import Player
-from exclock.util import get_real_sound_filename, get_time_delta_from_str, notify_all
+from exclock.util import get_real_sound_filename, get_time_delta_from_str, notify_all_term
 
-DEFAULT_TITLE = "ExClock"
+DEFAULT_TITLE = 'ExClock'
 
 
 def inner_str(s: str, d: dict) -> str:
     start_secs: List[int] = []
     end_secs: List[int] = []
     for i, c in enumerate(s):
-        if len(start_secs) == len(end_secs) and c == "{":
+        if len(start_secs) == len(end_secs) and c == '{':
             start_secs.append(i)
-        if len(start_secs) == len(end_secs) + 1 and c == "}":
+        if len(start_secs) == len(end_secs) + 1 and c == '}':
             end_secs.append(i)
 
     calcs = dict()
@@ -30,7 +30,7 @@ def inner_str(s: str, d: dict) -> str:
         calcs[target] = eval(target, {}, d)
 
     for key, val in calcs.items():
-        s = s.replace("{" + key + "}", str(val))
+        s = s.replace('{' + key + '}', str(val))
     return s
 
 
@@ -49,13 +49,13 @@ class Sound:
 
     @classmethod
     @contract(
-        lambda json: "message" in json,
-        lambda json: isinstance(json.get("sound_filename", "dummy"), str),
+        lambda json: 'message' in json,
+        lambda json: isinstance(json.get('sound_filename', 'dummy'), str),
     )
     def from_dict(cls, json: dict) -> Sound:
         return Sound(
-            message=json["message"],
-            sound_filename=get_real_sound_filename(json.get("sound_filename")),
+            message=json['message'],
+            sound_filename=get_real_sound_filename(json.get('sound_filename')),
         )
 
     @contract(lambda other: type(other) == Sound)
@@ -82,8 +82,8 @@ class ClockTimer:
         secs = list(sounds.keys())
         for i, (sec, sound) in enumerate(sounds.items()):
             spend_sec = secs[i] - (0 if i == 0 else secs[i - 1])
-            message = inner_str(sound.message, {"count": count})
-            notify_all(
+            message = inner_str(sound.message, {'count': count})
+            notify_all_term(
                 title=self.title,
                 message=message,
                 spend_sec=spend_sec,
@@ -105,12 +105,12 @@ class ClockTimer:
     @classmethod
     @contract(
         lambda json: isinstance(json, dict),
-        lambda json: "sounds" in json,
+        lambda json: 'sounds' in json,
     )
     def from_dict(cls, json: dict) -> ClockTimer:
         sounds = {}
-        for sec, sound in json["sounds"].items():
+        for sec, sound in json['sounds'].items():
             sec = get_time_delta_from_str(sec)
             sounds[sec] = Sound.from_dict(sound)
 
-        return ClockTimer(sounds=sounds, loop=json.get("loop", 1), title=json["title"])
+        return ClockTimer(sounds=sounds, loop=json.get('loop', 1), title=json['title'])
