@@ -10,16 +10,18 @@ from typing import List, Optional
 
 from ycontract import contract
 
+from exclock.rumps_app import RumpsApp
 from exclock.sound_player import Player
 from exclock.util import (
     DEFAULT_RING_FILENAME,
+    PLATFORM,
     convert_specific_time_to_time_delta,
     get_real_sound_filename,
     get_specific_time_from_str,
     get_time_delta_from_str,
     is_specific_time_str,
     is_time_delta_str,
-    notify_all,
+    notify_all_term,
 )
 
 
@@ -55,25 +57,33 @@ def main(opt: optparse.Values, args: List[str]) -> None:
     is_specific_time = is_specific_time_str(opt.time)
 
     if spend_sec is None:
-        print("time format is illegal.", file=stderr)
+        print('time format is illegal.', file=stderr)
         exit(1)
 
     if is_specific_time:
         hour, min_, sec = get_specific_time_from_str(opt.time)
-        sec_str = "" if sec == 0 else f":{sec:02d}"
-        print(f"sleep until {hour:02d}:{min_:02d}{sec_str}")
+        sec_str = '' if sec == 0 else f':{sec:02d}'
+        print(f'sleep until {hour:02d}:{min_:02d}{sec_str}')
 
     try:
         ring_sound_filename = get_ring_filename(opt.ring_filename)
         if not Path(ring_sound_filename).exists():
-            print("Ring filename is not found.", file=stderr)
+            print('Ring filename is not found.', file=stderr)
             exit(1)
 
-        message = f"Specified time is passed(sec={spend_sec})."
-        notify_all(title="⏰ Exclock ⏰", message=message, spend_sec=spend_sec, is_first=False)
+        message = f'Specified time is passed(sec={spend_sec}).'
+        if PLATFORM == 'Darwin':
+            RumpsApp(
+                clock_title='⏰ Exclock ⏰',
+                message=message,
+                ring_filename=ring_sound_filename,
+                maxsec=spend_sec).run()
+        else:
+            notify_all_term(
+                title='⏰ Exclock ⏰', message=message, spend_sec=spend_sec, is_first=False)
 
-        p = Player(ring_sound_filename)
-        p.play()
+            p = Player(ring_sound_filename)
+            p.play()
     except KeyboardInterrupt:
         ...
     finally:
