@@ -5,21 +5,22 @@ import os
 import shutil
 from os.path import basename as _path_basename
 from pathlib import Path
+from platform import system as _platform_system
 from shlex import quote
-from sys import stdout
 from time import sleep as time_sleep
 from typing import List, Optional, Tuple
 
 from ycontract import contract
 
-DEFAULT_RING_FILENAME = "ring.mp3"
+DEFAULT_RING_FILENAME = 'ring.mp3'
 
-ASSET_DIR_IN_PROG = Path(__file__).parent.absolute().joinpath("assets")
-CLOCK_DIR_IN_PROG = ASSET_DIR_IN_PROG / "clock"
-SOUND_DIR_IN_PROG = ASSET_DIR_IN_PROG / "sound"
-ASSET_DIR_IN_SYS = Path(Path.home(), ".config", "exclock")
-CLOCK_DIR_IN_SYS = Path(os.getenv('EXCLOCK_CLOCK_DIR', str(ASSET_DIR_IN_SYS / "clock"))).absolute()
-SOUND_DIR_IN_SYS = Path(os.getenv('EXCLOCK_SOUND_DIR', str(ASSET_DIR_IN_SYS / "sound"))).absolute()
+ASSET_DIR_IN_PROG = Path(__file__).parent.absolute().joinpath('assets')
+CLOCK_DIR_IN_PROG = ASSET_DIR_IN_PROG / 'clock'
+SOUND_DIR_IN_PROG = ASSET_DIR_IN_PROG / 'sound'
+ASSET_DIR_IN_SYS = Path(Path.home(), '.config', 'exclock')
+CLOCK_DIR_IN_SYS = Path(os.getenv('EXCLOCK_CLOCK_DIR', str(ASSET_DIR_IN_SYS / 'clock'))).absolute()
+SOUND_DIR_IN_SYS = Path(os.getenv('EXCLOCK_SOUND_DIR', str(ASSET_DIR_IN_SYS / 'sound'))).absolute()
+PLATFORM = _platform_system()
 
 
 def executable(cmd: str) -> bool:
@@ -27,35 +28,35 @@ def executable(cmd: str) -> bool:
 
 
 def get_clock_basenames() -> List[str]:
-    clock_paths = set(CLOCK_DIR_IN_SYS.glob("**/*"))
-    clock_paths |= set(CLOCK_DIR_IN_PROG.glob("**/*"))
+    clock_paths = set(CLOCK_DIR_IN_SYS.glob('**/*'))
+    clock_paths |= set(CLOCK_DIR_IN_PROG.glob('**/*'))
 
     basenames = set()
     for clock_file in clock_paths:
         clock_filename = clock_file.name
-        if clock_filename.endswith(".json5"):
-            clock_filename = clock_filename[:-len(".json5")]
+        if clock_filename.endswith('.json5'):
+            clock_filename = clock_filename[:-len('.json5')]
         basenames.add(_path_basename(clock_filename))
 
     return sorted(list(basenames))
 
 
 def is_time_delta_str(s: str) -> bool:
-    if s == "":
+    if s == '':
         return False
 
     if s.isdigit():
         return True
 
-    mind = s.find("m")
+    mind = s.find('m')
     if mind != -1:
         s = s[mind + 1:]
 
-    sind = s.find("s")
+    sind = s.find('s')
     if sind != -1:
         s = s[sind + 1:]
 
-    return s == ""
+    return s == ''
 
 
 @contract(returns=lambda sec: sec >= 0)
@@ -64,11 +65,11 @@ def get_time_delta_from_str(s: str) -> int:
         return int(s)
     else:
         sec = 0
-        m_ind = s.find("m")
+        m_ind = s.find('m')
         if m_ind != -1:
             sec += 60 * int(s[:m_ind])
 
-        s_ind = s.find("s")
+        s_ind = s.find('s')
         if s_ind == -1:
             return sec
         sec += int(s[m_ind + 1:s_ind])
@@ -76,8 +77,8 @@ def get_time_delta_from_str(s: str) -> int:
 
 
 def is_specific_time_str(s: str) -> bool:
-    number_strs = s.split(":")
-    number_strs = [s.replace(" ", "") for s in number_strs]
+    number_strs = s.split(':')
+    number_strs = [s.replace(' ', '') for s in number_strs]
 
     if len(number_strs) not in (2, 3):
         return False
@@ -95,8 +96,8 @@ def is_specific_time_str(s: str) -> bool:
 
 @contract(is_specific_time_str, returns=lambda res: res[0] >= 0 and res[1] >= 0 and res[2] >= 0)
 def get_specific_time_from_str(s: str) -> Tuple[int, int, int]:
-    number_strs = s.split(":")
-    number_strs = [s.replace(" ", "") for s in number_strs]
+    number_strs = s.split(':')
+    number_strs = [s.replace(' ', '') for s in number_strs]
 
     numbers = list(map(int, number_strs))
     hour, min_, *secs = numbers
@@ -124,7 +125,7 @@ def get_real_json_filename(path: str) -> str:
 
     if not Path(path).exists() and not (CLOCK_DIR_IN_SYS /
                                         path).exists() and Path(path).suffix == '':
-        path += ".json5"
+        path += '.json5'
 
     if Path(path).exists():
         return path
@@ -153,29 +154,24 @@ def get_real_sound_filename(path_: Optional[str]) -> str:
     return str(SOUND_DIR_IN_PROG / str(path))
 
 
-def notify(title: str, message: str, cmd_io=None) -> None:
+def notify(title: str, message: str) -> None:
     if executable('terminal-notifier'):
         title = quote(title)
         message = quote(message)
         cmd = f'(terminal-notifier -title {title} -message {message}) &'
     else:  # use xmessage
-        message = quote(title + "\n" + message)
+        message = quote(title + '\n' + message)
         cmd = f'(xmessage -nearmouse -timeout 20 -buttons Close {message}) &'
 
-    if cmd_io is None:
-        os.system(cmd)
-    else:
-        print(cmd, file=cmd_io)
+    os.system(cmd)
 
 
 @contract(lambda spend_sec: spend_sec >= 0)
-def notify_all(
+def notify_all_term(
     title: str,
     message: str,
     spend_sec: int,
     is_first: bool,
-    out_io=stdout,
-    cmd_io=None,
 ) -> None:
     if spend_sec == 0:
         time_sleep(spend_sec)
@@ -183,10 +179,10 @@ def notify_all(
         for i in range(spend_sec):
             time_sleep(1)
             percent = int(100 * i / spend_sec)
-            print(f"\r  {i} / {spend_sec}    {percent}%", end="")
+            print(f'\r  {i} / {spend_sec}    {percent}%', end='')
         print()
 
     if not is_first:
-        notify(title=title, message=message, cmd_io=cmd_io)
+        notify(title=title, message=message)
 
-    print(message, file=out_io)
+    print(message)
